diff --git a/gfx/filters/dark.c b/gfx/filters/darken.c
similarity index 97%
rename from gfx/filters/dark.c
rename to gfx/filters/darken.c
index 3ae389d3c3..9678e8c1e2 100644
--- a/gfx/filters/dark.c
+++ b/gfx/filters/darken.c
@@ -13,7 +13,7 @@
* If not, see .
*/
// Compile: gcc -o dark.so -shared dark.c -std=c99 -O3 -Wall -pedantic -fPIC
#include "softfilter.h"
#include
@@ -147,7 +147,7 @@ static const struct softfilter_implementation darken = {
darken_threads,
darken_output,
darken_packets,
- "Dark",
+ "Darken",
SOFTFILTER_API_VERSION,
};
@@ -13,7 +13,7 @@
* If not, see .
*/
-// Compile: gcc -o dark.so -shared dark.c -std=c99 -O3 -Wall -pedantic -fPIC
+// Compile: gcc -o darken.so -shared darken.c -std=c99 -O3 -Wall -pedantic -fPIC
#include "softfilter.h"
#include